@@ -12,7 +12,7 @@
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: calculator.h 4744 2011-12-24 19:46:17Z axel $
+**   $Id: calculator.h 5055 2012-04-16 13:08:32Z axel $
 **
 ***********************************************************************/
 
@@ -708,7 +708,7 @@ private: // Private methods
   /**
    * Distributes a flight mode change.
    */
-  void flightModeChanded(Calculator::FlightMode);
+  void newFlightMode(Calculator::FlightMode);
 
 private: // Private attributes
   /** Contains the last flight sample */
