@@ -7,12 +7,12 @@
 ************************************************************************
 **
 **   Copyright (c):  2002      by Heiner Lamprecht
-**                   2007-2011 by Axel Pauli
+**                   2007-2012 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: flighttask.cpp 4675 2011-09-18 16:58:14Z axel $
+**   $Id: flighttask.cpp 4758 2012-01-04 21:29:25Z axel $
 **
 **   This class provides calculation, drawing and other support
 **   for flight tasks and contains the data of a task.
@@ -256,9 +256,11 @@ void FlightTask::__determineTaskType()
               flightType = FlightTask::FAI_S3;
               distance_task = distance_task_d;
             }
+          break;
 
         default:
           flightType = FlightTask::Unknown;
+          break;
         }
     }
   else
@@ -628,8 +630,8 @@ void FlightTask::drawTask( QPainter* painter, QList<Waypoint*> &drawnTp )
   const int h = Map::getInstance()->size().height();
 
   // Set pen color and width for the course line
-  QColor courseLineColor = conf->getTaskCourseLineColor();
-  qreal courseLineWidth  = conf->getTaskCourseLineWidth();
+  QColor courseLineColor = conf->getTargetLineColor();
+  qreal courseLineWidth  = conf->getTargetLineWidth();
 
   // qDebug("QDesktop: w=%d, h=%d, ora=%d", w, h, ora );
 
@@ -805,8 +807,8 @@ void FlightTask::circleSchemeDrawing( QPainter* painter, QList<Waypoint*> &drawn
   const int h = Map::getInstance()->size().height();
 
   // Set pen color and width for the course line
-  QColor courseLineColor = conf->getTaskCourseLineColor();
-  qreal courseLineWidth  = conf->getTaskCourseLineWidth();
+  QColor courseLineColor = conf->getTargetLineColor();
+  qreal courseLineWidth  = conf->getTargetLineWidth();
 
   QRect viewport( -10-r, -10-r, w+2*r, h+2*r );
 
