@@ -6,7 +6,7 @@
  ported to Qt4.x/X11  : (C) 2007-2012 by Axel Pauli
  maintainer           : axel@kflog.org
 
- $Id: mainwindow.cpp 5033 2012-03-27 20:08:40Z axel $
+ $Id: mainwindow.cpp 5058 2012-04-16 13:41:39Z axel $
 
 ****************************************************************************/
 
@@ -154,7 +154,7 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
 
 #ifdef ANDROID
       appFont.setFamily( "Droid Sans" );
-      appFSize = 12;
+      appFSize = 10;
 #else
 #ifdef MAEMO
       appFont.setFamily("Nokia Sans");
@@ -195,6 +195,11 @@ MainWindow::MainWindow( Qt::WindowFlags flags ) : QMainWindow( 0, flags )
           appFt.pixelSize(),
           appFt.weight() );
 
+  // report font height in pixels
+  QFontMetrics fm(appFt);
+
+  qDebug() << "QAppFontHeight=" << fm.boundingRect("XM").height() << "px";
+
   // For Maemo it's really better to adapt the size of some common widget
   // elements. That is done with the help of the class MaemoStyle.
   qDebug() << "GuiStyles:" << QStyleFactory::keys();
@@ -1006,7 +1011,7 @@ void MainWindow::slotSetMenuBarFontSize()
     {
       // take current font as alternative
       userFont = font();
-      minFontSize = 16;
+      minFontSize = 14;
     }
 
   if( userFont.pointSize() != -1 && userFont.pointSize() < minFontSize )
