@@ -8,12 +8,12 @@
  **
  **   Copyright (c):  2001      by Heiner Lamprecht,
  **                   2002      by André Somers
- **                   2008-2011 by Axel Pauli
+ **                   2008-2012 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: mapconfig.cpp 4709 2011-11-21 08:18:37Z axel $
+ **   $Id: mapconfig.cpp 5024 2012-03-23 13:27:08Z axel $
  **
  ***********************************************************************/
 
@@ -22,9 +22,11 @@
 #include <QtGui>
 
 #include "basemapelement.h"
-#include "mapdefaults.h"
 #include "generalconfig.h"
+#include "layout.h"
 #include "mapcalc.h"
+#include "mapconfig.h"
+#include "mapdefaults.h"
 
 // Different macros used by read method for configuration data
 #define READ_BORDER(a) \
@@ -950,12 +952,7 @@ QPixmap& MapConfig::getPlusButton()
   if( first )
     {
       first = false;
-
-#ifndef MAEMO
-      int size = 50;
-#else
-      int size = 70;
-#endif
+      int size = MapPMButtonSize;
 
       plusButton = QPixmap( size+6, size+6 );
       plusButton.fill(Qt::transparent);
@@ -984,12 +981,8 @@ QPixmap& MapConfig::getMinusButton()
   if( first )
     {
       first = false;
+      int size = MapPMButtonSize;
 
-#ifndef MAEMO
-      int size = 50;
-#else
-      int size = 70;
-#endif
       minusButton = QPixmap( size+6, size+6 );
       minusButton.fill(Qt::transparent);
       QPainter painter(&minusButton);
