@@ -8,7 +8,7 @@
 
     email                : axel@kflog.org
 
-    $Id: mapinfobox.h 5015 2012-03-21 10:07:14Z axel $
+    $Id: mapinfobox.h 5054 2012-04-13 13:02:13Z axel $
 
  ***************************************************************************/
 
@@ -81,7 +81,7 @@ protected:
  *
  * \date 2002-2012
  *
- * \version $Id: mapinfobox.h 5015 2012-03-21 10:07:14Z axel $
+ * \version $Id: mapinfobox.h 5054 2012-04-13 13:02:13Z axel $
  *
  */
 class MapInfoBox : public QFrame
@@ -159,7 +159,7 @@ public:
   /**
    * Read property of QString _value.
    */
-  const QString& getValue()
+  const QString& getValue() const
   {
     return _value;
   };
@@ -167,15 +167,20 @@ public:
   /**
    * Returns the pretext label widget.
    */
-  QLabel* getPreTextLabelWidget()
+  QLabel* getPreTextLabelWidget() const
   {
     return _ptext;
   };
 
+  QWidget* getPreWidget() const
+  {
+    return _preWidget;
+  };
+
   /**
    * Returns the text label widget.
    */
-  QLabel* getTextLabelWidget()
+  QLabel* getTextLabelWidget() const
   {
     return _text;
   };
