@@ -7,29 +7,29 @@
 ************************************************************************
 **
 **   Copyright (c):  2003      by André Somers
-**                   2008-2011 by Axel Pauli
+**                   2008-2012 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: preflightgliderpage.cpp 4722 2011-12-19 16:20:34Z axel $
+**   $Id: preflightgliderpage.cpp 4776 2012-01-10 20:42:22Z axel $
 **
 ***********************************************************************/
 
-#include <QLabel>
-#include <QPushButton>
-#include <QGridLayout>
-#include <QToolTip>
+#include <QtGui>
 
 #include "glider.h"
 #include "calculator.h"
-#include "preflightgliderpage.h"
 #include "generalconfig.h"
+#include "layout.h"
+#include "preflightgliderpage.h"
+#include "varspinbox.h"
 
-PreFlightGliderPage::PreFlightGliderPage(QWidget *parent) : QWidget(parent)
+PreFlightGliderPage::PreFlightGliderPage(QWidget *parent) :
+  QWidget(parent),
+  lastGlider(0)
 {
   setObjectName("PreFlightGliderPage");
-  lastGlider = 0;
   int row = 0;
 
   QGridLayout* topLayout = new QGridLayout(this);
@@ -43,34 +43,35 @@ PreFlightGliderPage::PreFlightGliderPage(QWidget *parent) : QWidget(parent)
 
   QLabel* lblLoad = new QLabel(tr("Added load:"), this);
   topLayout->addWidget(lblLoad, row, 2);
-  spinLoad=new QSpinBox(this);
-  topLayout->addWidget(spinLoad, row, 3);
-  spinLoad->setButtonSymbols(QSpinBox::PlusMinus);
-  spinLoad->setMinimum(0);
-  spinLoad->setMaximum(1000);
+  spinLoad = new QSpinBox(this);
+  spinLoad->setRange(0, 1000);
   spinLoad->setSingleStep(5);
   spinLoad->setSuffix(" kg");
+  hspinLoad = new VarSpinBox(spinLoad);
+  hspinLoad->setEnabled(false);
+  topLayout->addWidget(hspinLoad, row, 3);
   row++;
 
   QLabel* lblCoPilot = new QLabel(tr("Copilot:"), this);
   topLayout->addWidget(lblCoPilot, row, 0);
-  edtCoPilot=new QLineEdit(this);
+  edtCoPilot = new QLineEdit(this);
   topLayout->addWidget(edtCoPilot, row, 1);
 
   QLabel* lblWater = new QLabel(tr("Water ballast:"), this);
   topLayout->addWidget(lblWater, row, 2);
-  spinWater=new QSpinBox(this);
-  topLayout->addWidget(spinWater, row, 3);
-  spinWater->setButtonSymbols(QSpinBox::PlusMinus);
-  spinWater->setMinimum(0);
-  spinWater->setMaximum(300);
+  spinWater = new QSpinBox(this);
+  spinWater->setRange(0, 500);
   spinWater->setSingleStep(5);
   spinWater->setSuffix(" l");
+  hspinWater = new VarSpinBox(spinWater);
+  hspinWater->setEnabled(false);
+  topLayout->addWidget(hspinWater, row, 3);
   row++;
 
   QLabel* lblWLoad = new QLabel(tr("Wing load:"), this);
   topLayout->addWidget(lblWLoad, row, 2);
-  wingLoad=new QLabel(this);
+  wingLoad = new QLabel;
+  wingLoad->setFocusPolicy(Qt::NoFocus);
   topLayout->addWidget(wingLoad, row, 3);
   row++;
 
@@ -78,36 +79,31 @@ PreFlightGliderPage::PreFlightGliderPage(QWidget *parent) : QWidget(parent)
   row++;
 
   list = new GliderListWidget(this);
+  list->setToolTip(tr("Select a glider to be used"));
   topLayout->addWidget(list, row, 0, 1, 4);
   row++;
 
+  //---------------------------------------------------------------------
   QPushButton* deselect = new QPushButton( tr("Deselect"), this );
   deselect->setToolTip( tr("Clear glider selection") );
   topLayout->addWidget( deselect, row, 0 );
 
+  //---------------------------------------------------------------------
   list->fillList();
   list->clearSelection();
   getCurrent();
 
-  connect(deselect, SIGNAL(clicked()),
-          this, SLOT(slot_gliderDeselected()) );
-
-  connect(list, SIGNAL(itemSelectionChanged()),
-          this, SLOT(slot_gliderChanged()));
-
-  connect( spinLoad, SIGNAL(valueChanged(int)),
-           this, SLOT(slot_updateWingLoad(int)) );
-
-  connect( spinWater, SIGNAL(valueChanged(int)),
-           this, SLOT(slot_updateWingLoad(int)) );
+  connect(deselect, SIGNAL(clicked()), this, SLOT(slotGliderDeselected()) );
+  connect(list, SIGNAL(itemSelectionChanged()), this, SLOT(slotGliderChanged()));
 }
 
 PreFlightGliderPage::~PreFlightGliderPage()
-{}
-
-void PreFlightGliderPage::slot_gliderChanged()
 {
-  // save copilot before new selection
+}
+
+void PreFlightGliderPage::slotGliderChanged()
+{
+  // save co-pilot before new selection
   if(lastGlider)
     {
       if (lastGlider->seats() == Glider::doubleSeater)
@@ -130,44 +126,58 @@ void PreFlightGliderPage::slot_gliderChanged()
       edtCoPilot->setText(glider->coPilot());
 
       spinLoad->setValue( (int) rint(glider->polar()->grossWeight() - glider->polar()->emptyWeight()) );
+      hspinLoad->setEnabled(true);
 
-      spinWater->setMaximum(glider->maxWater());
-      spinWater->setEnabled(glider->maxWater()!=0);
+      spinWater->setMaximum(glider->maxWater() );
+      hspinWater->setEnabled(glider->maxWater() != 0 );
+      spinWater->setValue(glider->polar()->water() );
     }
 
-  slot_updateWingLoad( 0 );
+  updateWingLoad();
 }
 
-void PreFlightGliderPage::slot_gliderDeselected()
+void PreFlightGliderPage::slotGliderDeselected()
 {
   // clear last stored glider
   lastGlider = static_cast<Glider *> (0);
+
   // clear list selection
   list->clearSelection();
-  // clear wing load
+
+  // clear spinboxes
+  spinLoad->setValue(0);
+  spinWater->setValue(0);
+
+  hspinLoad->setEnabled(false);
+  hspinWater->setEnabled(false);
+
+// clear wing load label
   wingLoad->setText("");
 }
 
 void PreFlightGliderPage::getCurrent()
 {
   extern Calculator* calculator;
+
   Glider* glider = calculator->glider();
 
   if( glider == static_cast<Glider *> (0) )
     {
       return;
     }
-//  qDebug("## c2 ## reg %s", glider->registration().toLatin1().data() );
+
   list->selectItemFromReg( glider->registration() );
 
   edtCoPilot->setEnabled(glider->seats() == Glider::doubleSeater);
   edtCoPilot->setText(glider->coPilot());
 
   spinLoad->setValue( (int) (glider->polar()->grossWeight() - glider->polar()->emptyWeight()) );
+  hspinLoad->setEnabled(true);
 
   spinWater->setMaximum(glider->maxWater());
-  spinWater->setEnabled(glider->maxWater()!=0);
+  hspinWater->setEnabled(glider->maxWater() != 0);
   spinWater->setValue(glider->polar()->water());
+
   lastGlider = list->getSelectedGlider();
 }
 
@@ -180,7 +190,7 @@ void PreFlightGliderPage::save()
 
   if(glider)
     {
-      if (glider->seats()==Glider::doubleSeater)
+      if (glider->seats() == Glider::doubleSeater)
         {
           glider->setCoPilot(edtCoPilot->text());
         }
@@ -190,11 +200,11 @@ void PreFlightGliderPage::save()
         }
 
       glider->polar()->setGrossWeight(spinLoad->value() + glider->polar()->emptyWeight() );
-      glider->polar()->setWater(spinWater->value(),0);
+      glider->polar()->setWater(spinWater->value(), 0);
       // @AP: save changed added load permanently
       list->save();
       // @AP: take glider from list
-      glider=list->getSelectedGlider(true);
+      glider = list->getSelectedGlider(true);
       calculator->setGlider(glider);
       list->setStoredSelection(glider);
     }
@@ -206,10 +216,8 @@ void PreFlightGliderPage::save()
     }
 }
 
-void PreFlightGliderPage::slot_updateWingLoad( int value )
+void PreFlightGliderPage::updateWingLoad()
 {
-  Q_UNUSED(value)
-
   Glider* glider = list->getSelectedGlider();
 
   if( glider == 0 || glider->polar() == 0 || glider->polar()->wingArea() == 0.0 )
@@ -241,6 +249,6 @@ void PreFlightGliderPage::slot_updateWingLoad( int value )
 
 void PreFlightGliderPage::showEvent(QShowEvent *)
 {
-  slot_gliderChanged();
+  slotGliderChanged();
   list->setFocus();
 }
