@@ -6,12 +6,12 @@
 **
 ************************************************************************
 **
-**   Copyright (c):  2007-2011 by Axel Pauli
+**   Copyright (c):  2007-2012 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: settingspagetask.h 4718 2011-12-08 19:24:23Z axel $
+**   $Id: settingspagetask.h 5010 2012-03-16 12:44:07Z axel $
 **
 ***********************************************************************/
 
@@ -22,9 +22,9 @@
  *
  * \brief Configuration settings for flight tasks.
  *
- * \date 2007-2011
+ * \date 2007-2012
  *
- * \version $Id: settingspagetask.h 4718 2011-12-08 19:24:23Z axel $
+ * \version $Id: settingspagetask.h 5010 2012-03-16 12:44:07Z axel $
  *
  */
 
@@ -33,6 +33,7 @@
 
 #include <QWidget>
 #include <QCheckBox>
+#include <QLabel>
 #include <QSpinBox>
 #include <QButtonGroup>
 #include <QGroupBox>
@@ -55,6 +56,12 @@ public:
 
   virtual ~SettingsPageTask();
 
+protected:
+
+  virtual void showEvent(QShowEvent *);
+
+  virtual void hideEvent(QHideEvent *);
+
 public slots:
 
   void slot_load();
@@ -103,6 +110,7 @@ private:
   QSpinBox*    tlWidth;
   QPushButton* tlColorButton;
   QCheckBox*   tlCheckBox;
+  QLabel*      tlColorLabel;
 
   // temporary storage of target line color
   QColor tlColor;
@@ -116,6 +124,7 @@ private:
   QSpinBox*    trWidth;
   QPushButton* trColorButton;
   QCheckBox*   trCheckBox;
+  QLabel*      trColorLabel;
 
   // temporary storage of track line color
   QColor trColor;
@@ -137,6 +146,9 @@ private:
   double loadedInnerSectorRadius;
   // store outer sector radius after load
   double loadedOuterSectorRadius;
+
+  /** Auto sip flag storage. */
+  bool m_autoSip;
 };
 
 #endif
