@@ -6,17 +6,17 @@
 **
 ************************************************************************
 **
-**   Copyright (c):  2007-2010 Axel Pauli, axel@kflog.org
+**   Copyright (c):  2007-2012 Axel Pauli, axel@kflog.org
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: tpinfowidget.cpp 4597 2011-04-28 18:55:45Z axel $
+**   $Id: tpinfowidget.cpp 4899 2012-02-01 13:30:43Z axel $
 **
 ************************************************************************/
 
 #include <cmath>
-#include <time.h>
+#include <ctime>
 
 #include <QtGui>
 
@@ -31,15 +31,12 @@
 #include "sonne.h"
 #include "time_cu.h"
 
-extern MapConfig    *_globalMapConfig;
-extern MapContents  *_globalMapContents;
-extern Calculator       *calculator;
+extern MapContents*  _globalMapContents;
+extern Calculator*   calculator;
 
 TPInfoWidget::TPInfoWidget( QWidget *parent ) :
   QWidget( parent )
 {
-  // qDebug("TPInfoWidget::TPInfoWidget");
-
   setObjectName("TPInfoWidget");
   setAttribute( Qt::WA_DeleteOnClose );
   this->parent = parent;
@@ -74,10 +71,12 @@ TPInfoWidget::TPInfoWidget( QWidget *parent ) :
   timer = new QTimer(this);
   connect(timer, SIGNAL(timeout()), this, SLOT(slot_Timeout()));
 
-  // activate keyboard shortcut cancel for close of widget
-  QShortcut* scClose = new QShortcut( this );
-  scClose->setKey( Qt::Key_Escape );
-  connect( scClose, SIGNAL(activated()), this, SLOT( slot_Close() ));
+  // activate keyboard shortcuts for closing of widget
+  connect( new QShortcut( Qt::Key_Escape, this ), SIGNAL(activated()),
+           this, SLOT( slot_Close() ));
+
+  connect( new QShortcut( Qt::Key_Close, this ), SIGNAL(activated()),
+           this, SLOT( slot_Close() ));
 }
 
 TPInfoWidget::~TPInfoWidget()
@@ -373,6 +372,7 @@ void TPInfoWidget::prepareSwitchText( const int currentTpIndex,
           case ReachablePoint::belowSafety:
             display += "<td>&nbsp;&nbsp;" + tr("Arrival Alt") + "</td><td><b><font color=\"#FF00FF\">" +
               arrivalAlt.getText(true,0) + "</font></b></td></tr>";
+            break;
           }
       }
     else
@@ -576,7 +576,7 @@ void TPInfoWidget::prepareArrivalInfoText( Waypoint *wp )
       // In some areas no results available. In this case we skip
       // this output.
       display += "<tr><td>&nbsp;&nbsp;" + tr("Sunset") + "</td><td align=\"left\"><b>" +
-        ss + " " + "</b></td></tr>";
+        ss + " " + tz + "</b></td></tr>";
     }
 
   //----------------------------------------------------------------------------
@@ -656,6 +656,7 @@ void TPInfoWidget::prepareArrivalInfoText( Waypoint *wp )
           case ReachablePoint::belowSafety:
             display += "<tr><td>&nbsp;&nbsp;" + tr("Arrival Alt") + "</td><td><b><font color=\"#FF00FF\">" +
               arrivalAlt.getText(true,0) + "</font></b></td><tr>";
+            break;
           }
       }
 
@@ -700,7 +701,7 @@ void TPInfoWidget::prepareArrivalInfoText( Waypoint *wp )
         // In some areas no results available. In this case we skip
         // this output.
         display += "<tr><td>&nbsp;&nbsp;" + tr("Sunset") + "</td><td align=\"left\"><b>" +
-                    ss + " " + "</b></td></tr>";
+                    ss + " " + tz + "</b></td></tr>";
        }
 
     display += "</table></big></html>";
